#!/usr/bin/env python

__author__ = "Martin Kuemmel <mkuemmel@eso.org>"
__date__ = "$Date: 2010-05-07 06:11:19 $"
__version__ = "$Revision: 1.11 $"
__credits__ = """
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
"""

import os, os.path,string, sys
from   distutils.core import setup
from   distutils.sysconfig import get_python_lib

def getDataDir(args):
    ver = sys.version_info
    python_exec = 'python' + str(ver[0]) + '.' + str(ver[1])
    for a in args:
        if string.find(a, '--home=') == 0:
            dir = string.split(a, '=')[1]
            data_dir = os.path.join(dir, 'lib/python/aXe2html/')
        elif string.find(a, '--prefix=') == 0:
            dir = string.split(a, '=')[1]
            data_dir = os.path.join(dir, 'lib', python_exec, 'site-packages/aXe2html/')
            pack_dir = os.path.join(dir, 'lib', python_exec, 'site-packages')
            if os.getenv('PYTHONPATH') == None:
                os.environ['PYTHONPATH'] = pack_dir
                print ''
                print 'The directory: ', pack_dir
                print 'was put TEMPORARILY on the PYTHONPATH to make the inline'
                print 'documentation. To use aXe2web you should put that directory'
                print 'in your searchpath!'
                print ''
            else:
                ppath = os.getenv('PYTHONPATH')
                if ppath.find(pack_dir) < 0:
                    ppath = ppath + ':' + pack_dir
                    os.environ['PYTHONPATH'] = pack_dir
                    print ''
                    print 'The directory: ', pack_dir
                    print 'was put TEMPORARILY on the PYTHONPATH to make the inline'
                    print 'documentation. To use aXe2web you should put that directory'
                    print 'in your searchpath!'
                    print ''
        elif a.startswith('--install-data='):
            dir = string.split(a, '=')[1]
            data_dir = dir
        else:
            data_dir = os.path.join(sys.prefix, 'lib', python_exec, 'site-packages/aXe2html/')

    return data_dir

def makedocs(args):
    for a in args:
        if string.find(a, 'install') == 0:
            data_dir = getDataDir(args) + 'images'
            docs_dir = getDataDir(args) + 'doc'
            home_dir = os.getcwd()
            loc_docs = home_dir + '/aXe2html/doc'
#           os.chdir(loc_docs)
#           print 'Making the documentation: '
#           print 'I went to: ', loc_docs
#           for oneitem in docitems:
#               commstring = 'pydoc -w ' + oneitem
#               os.system(commstring)

            os.chdir(docs_dir)
            print ''
            print 'Making the inline documentation at:'
            print docs_dir
            print ''
            for oneitem in docitems:
                commstring = 'pydoc -w ' + oneitem
                os.system(commstring)

            os.chdir(home_dir)
            print 'Going back to: ', home_dir
            startfile = docs_dir + '/aXe2web_help.html'
            return startfile
    return 1

#------------------
#  Check for the matplotlib - library
try:
    import matplotlib
    print "matplotlib library found!\n"
except:
    print "matplotlib library not properly installed!\n"
    sys.exit(1)


#------------------
#  Check for the pyfits - library
try:
    import pyfits
    print "pyfits library found!\n"
except:
    print "pyfits library not properly installed!\n"
    sys.exit(1)

#imversion = ''
imversion = string.split(pyfits.__version__,'.')[0] + string.split(string.split(pyfits.__version__,'.')[1])[0]
#for item in string.split(pyfits.__version__,'.'):
#    imversion = imversion + item[0]
if int(imversion) < 8:
    print "pyfits 0.8.0 and higher required!"
    print "You have: ", pyfits.__version__, "\n"
    print "You may download the required version under:"
    print "http://www.stsci.edu/resources/software_hardware/pyfits\n"
    sys.exit(1)

data_dir = getDataDir(sys.argv) + 'images'
docs_dir = getDataDir(sys.argv) + 'doc'


#------------------
#  The 'normal' setup
setup(name="aXe2html",
      version="1.2",
      description="Visualization of aXe-extracted objects",
      author="Martin Kuemmel",
      author_email="mkuemmel@eso.org",
      license='LGPL',
      url="http://www.stecf.org/software/aXe/index.html",
      scripts = ['./aXe2html/bin/aXe2web'],
      packages=['aXe2html', 'aXe2html.cathtml',\
                'aXe2html.irafims','aXe2html.sexcat','aXe2html.spectra',\
                'aXe2html.utils','aXe2html.asciidata'],
      data_files = [(data_dir,['aXe2html/images/nodimage.gif']),\
                    (data_dir,['aXe2html/images/nodimage.jpg']),\
                    (data_dir,['aXe2html/images/nodimage.png']),\
                    (data_dir,['aXe2html/images/nogimage.gif']),\
                    (data_dir,['aXe2html/images/nogimage.jpg']),\
                    (data_dir,['aXe2html/images/nogimage.png']),\
                    (data_dir,['aXe2html/images/noplot.gif']),\
                    (data_dir,['aXe2html/images/noplot.jpg']),\
                    (data_dir,['aXe2html/images/noplot.png']),\
                    (data_dir,['aXe2html/images/ACS_aXevis03.jpg']),\
                    (data_dir,['aXe2html/images/ACS_aXe03.jpg']),
                    (data_dir,['aXe2html/images/ind_page.png']),
                    (data_dir,['aXe2html/images/inf_page.png']),
                    (data_dir,['aXe2html/images/ob_page.png']),
                    (data_dir,['aXe2html/images/ov_page.png']),
                    (data_dir,['aXe2html/images/axe_css1.png']),
                    (data_dir,['aXe2html/images/axe_css2.png']),
                    (data_dir,['aXe2html/images/axe_default.css']),
                    (data_dir,['aXe2html/images/favicon.ico']),
                    (docs_dir,['aXe2html/doc/aXe2web.par']),
                    (docs_dir,['aXe2html/doc/aXe2web_help.html'])],
     )


docitems = ['aXe2html',\
           'aXe2html.cathtml',\
#           'aXe2html.cathtml.axecell',\
#           'aXe2html.cathtml.imagecell',\
#           'aXe2html.cathtml.textcell',\
#           'aXe2html.cathtml.htmlcat',\
#           'aXe2html.cathtml.pagemaker',\
           'aXe2html.irafims',\
           'aXe2html.irafims.implotmaker', \
           'aXe2html.irafims.irafimtools',\
           'aXe2html.sexcat',\
           'aXe2html.sexcat.colheader',\
           'aXe2html.sexcat.correlators',\
           'aXe2html.sexcat.sextractcat', \
           'aXe2html.sexcat.tablecolumn',\
           'aXe2html.spectra',\
           'aXe2html.spectra.plot_spc',\
           'aXe2html.spectra.outdata',\
           'aXe2html.utils',\
           'aXe2html.utils.commparser',\
           'aXe2html.utils.fitsheader',\
           'aXe2html.utils.fitsslicer',\
           'aXe2html.utils.mathlib', \
           'aXe2html.utils.messages',\
           'aXe2html.utils.namings', \
           'aXe2html.utils.pos96parser',\
           'aXe2html.asciidata',\
            ]
