"""
$Revision: 1.2 $ $Date: 2010-08-25 06:47:17 $
Author: Martin Kuemmel
Affiliation: Space Telescope - European Coordinating Facility
"""
__author__ = "Martin Kuemmel <mkuemmel@eso.org>"
__date__ = "$Date: 2010-08-25 06:47:17 $"
__version__ = "$Revision: 1.2 $"
__credits__ = """This software was developed by the ACS group of the Space Telescope -
European Coordinating Facility (ST-ECF). The ST-ECF is a department jointly
run by the European Space Agency and the European Southern Observatory.
It is located at the ESO headquarters at Garching near Munich. The ST-ECF
staff supports the European astronomical community in exploiting the research
opportunities provided by the earth-orbiting Hubble Space Telescope.
"""

import aXe2html.utils.mathlib

class AxeCell:
    """
    Class to create and incorporate a table cell with axe-specific
    data in a table. Up to now that aXe-specific data are the
    pixel and world coordinates, which are shown in a table
    within the cell. However that can easily be changed/adopted.
    """
    def __init__(self, axedata, hclass=None):
        """
        Input:
            axedata - dictionary with axe-specific
                      data for one object

        Return:
            -

        Description:
            Stores the incoming data as instance varibles such
            that all information can be used later on.
            Transformes the degree variant of astronomical coordinates
            into the usual variant hh:mm:ss.s dd:mm:ss.s.
        """
        self.axedata = axedata
        self.radec = aXe2html.utils.mathlib.radectostring(self.axedata["X_WORLD"],self.axedata["Y_WORLD"])
        self.hclass=hclass

    def setcolhead(self, colhead):
        """
        Input:
            colhead - the column header

        Return:
            -

        Description:
            Sets an instance variable which can be
            used to specify the column header in a table.
        """
        self.colhead=colhead


    def getcolhead(self):
        """
        Input:
            -

        Return:
            -

        Description:
            Returns the column head variable.
        """

        return self.colhead


    def gethtml(self):
        """
        Input:
            -

        Return:
            htmlstring - the html-string representing the cell

        Description:
            Returns the the content of an aXe-cell in html-format.
        """
        htmlstring = '<td '
        if self.hclass and len(self.hclass) > 0:
            htmlstring += ' class="' + str(self.hclass) + '">'
        else:
            htmlstring += ' align="center">'
#       htmlstring = '<td align=center>'
        htmlstring = htmlstring + '<p>\nx = ' + str(self.axedata["X_IMAGE"]) + '<br>'
        htmlstring = htmlstring + 'y = ' + str(self.axedata["Y_IMAGE"]) + '</p>\n'
        htmlstring = htmlstring + '<p><table border=0>\n'
        htmlstring = htmlstring + '<tr><td align=left>ra: </td><td align=right>' + self.radec[0] + '</td></tr>\n'
        htmlstring = htmlstring + '<tr><td align=left>dec:</td><td align=right>' + self.radec[1] + '</td></tr>\n'
        htmlstring = htmlstring + '</table></p>\n'

        if self.axedata['SPECIAL'] != None:
            htmlstring = htmlstring + '<p>\n%s = %.2f</p>\n' % (self.axedata['SPNAME'], self.axedata['SPECIAL'])

        htmlstring = htmlstring + '</td>\n'

        return htmlstring
