"""
$Revision: 1.4 $ $Date: 2010-08-26 07:47:08 $
Author: Martin Kuemmel
Affiliation: Space Telescope - European Coordinating Facility
"""
__author__ = "Martin Kuemmel <mkuemmel@eso.org>"
__date__ = "$Date: 2010-08-26 07:47:08 $"
__version__ = "$Revision: 1.4 $"
__credits__ = """This software was developed by the ACS group of the Space Telescope -
European Coordinating Facility (ST-ECF). The ST-ECF is a department jointly
run by the European Space Agency and the European Southern Observatory.
It is located at the ESO headquarters at Garching near Munich. The ST-ECF
staff supports the European astronomical community in exploiting the research
opportunities provided by the earth-orbiting Hubble Space Telescope.
"""

import string, math
import aXe2html.utils.namings

class HTMLCat:
    """
    Class for the actual html-pages. Each instances holds a file
    in html format. By calling the various methods that file is
    filled with content, to say a header, title, subtitle,
    table(s), links and so on.
    There is no predefined format or limit. Pages can be done
    at will using the elements offert.
    """
    def __init__(self, filename, page_root, actpage, pagesize):
        """
        Input:
            filename  - the name of the html document
            page_root - the root name used for all html documents
                        in the series
            actpage   - the number of the page in the actual series
            pagesize  - the number of aXe-objects per table

        Return:
            -

        Description:
            Converts the parameters into instance variables.
            some of them are only seldomly used, and dummy
            values are fine if they are useless.
        """
        self.filename    = filename
        self.page_root   = page_root
        self.actpage     = actpage
        self.pagesize    = pagesize
        self.prev_page   = None
        self.next_page   = None
        self.over_page   = None
        self.inde_page   = None
        self.info_page   = None
        self.prev_string = None
        self.next_string = None
        self.over_string = None
        self.inde_string = None
        self.info_string = None
        self.this_string = None
        self.oufile      = open(self.filename, 'w')
        self.decimage    = aXe2html.utils.namings.DecorationFiles()

    def closefile(self):
        """
        Input:
           -

        Return:
           -

        Description:
           Closes the file at the end.
        """
        self.oufile.close()


    def writehead(self, htmltitle, outpath, cssfile):
        """
        Input:
            htmltitle - the title of the document

        Return:
            -

        Description:
            Writes the page header to the document. That means everything
            up to the first content. Here is the space for desired backgrounds,
            fonts, general page headers and so on.
            up to now only sparsely used.
        """
        headstring = '<title> ' + htmltitle + '</title>\n'
        self.oufile.write('<!DOCTYPE HTML PUBLIC "-//W3C//DD HTML 4.01 Frameset//EN"\n')
        self.oufile.write('"http://www.w3.org/TR/html4/frameset.dtd">\n')
        self.oufile.write('<html\n>')
        self.oufile.write('<head>\n')
        self.oufile.write(headstring)

        self.oufile.write('<style type="text/css">\n')
        self.oufile.write('<!--\n')

        self.oufile.write('@import url('+self.decimage.getcssname(outpath, cssfile)+');\n')

        self.oufile.write('-->\n')
        self.oufile.write('</style>\n')

        self.oufile.write('</head>\n')

    def writetail(self):
        """
        Input:
            -

        Return:
            -    

        Description:
            Writes the end of the page. Here is space to create a general
            page appendix and so on.
        """
        self.oufile.write('Created by <a href="http://www.stecf.org/software/slitless_software/axe/axe2web.php"><b>aXe2web version 1.2</b></a><br>\n')
        self.oufile.write('<A href="mailto:mkuemmel@eso.org">Send comments to <TT>&lt;mkuemmel@eso.org&gt;</TT></A>\n')
        self.oufile.write('</body>\n')
        self.oufile.write('</html>\n')


    def writetitle(self, texttitle):
        """
        Input:
            texttitle - the title to appear

        Return:
            -    

        Description:
            Writes a title in <h1> into the document.
        """
        titlestring = '<h1 align=center> ' + texttitle + '</h1>\n'
        self.oufile.write(titlestring)

    def writenicetitle(self, texttitle, outpath, imgpath):
        """
        Input:
            texttitle - the title to appear

        Return:
            -    

        Description:
            Writes a title in <h1> into the document.
        """
        titlestring = '<table width="100%" align="center" border="0"><tr>'
        titlestring =  titlestring + '<td><a href="http://www.stecf.org/software/slitless_software/axe/axe2web.php"><img align="left" src="' +self.decimage.getvisimage(outpath, imgpath)+ \
                      '" alt="aXe-spectral extraction"></a></td>\n'
        titlestring = titlestring + '<td><h1 align=center> ' + texttitle + '</h1></td>\n'
        titlestring =  titlestring + '<td><a href="http://www.stecf.org/software/slitless_software/axe"><img align="right" src="' +self.decimage.getspeimage(outpath, imgpath)+ \
                      '" alt="aXe-spectral extraction"></a></td>\n'
        titlestring = titlestring + '</tr></table>\n'
        self.oufile.write(titlestring)

        # copy the favicon over
        self.decimage.getfavicon(outpath, imgpath)


    def writesubtitle(self, texttitle):
        """
        Input:
            texttitle - the subtitle to appear

        Return:
            -    

        Description:
            Writes a subtitle in <h1> into the document.
        """
        self.oufile.write('<p>')
        titlestring = '<h2 align=center> ' + texttitle + '</h2>\n'
        self.oufile.write(titlestring)
        self.oufile.write('<p>')


    def writesubsubtitle(self, texttitle):
        """
        Input:
            texttitle - the subsubtitle to appear

        Return:
            -    

        Description:
            Writes a subsubtitle in <h1> into the document.
        """
        self.oufile.write('<p>')
        titlestring = '<h3 align=center> ' + texttitle + '</h3>\n'
        self.oufile.write(titlestring)
        self.oufile.write('<p>')


    def writehorizontalrule(self):
        """
        Input:
            -

        Return:
            -    

        Description:
            Writes a horizontal rule
        """
        self.oufile.write('<p>')
        self.oufile.write('<hr>')
        self.oufile.write('<p>')


    def writeobjnums(self, actpage):
        """
        Input:
            actpage - the actual page number of the document

        Return:
            -    

        Description:
            Special form of a subtitle
        """
#       titlestring = '<h3 align=center> objects ' + self.linkstrings[actpage-1] + '</h3>\n'
        titlestring = '<h3 align=center> objects ' + self.this_string + '</h3>\n'
        self.oufile.write(titlestring)


    def opentab(self, html_class=None):
        """
        Input:
            -

        Return:
            -    

        Description:
            Opens a table
        """
        if html_class and len(html_class)  > 0:
            self.oufile.write('<table class="'+str(html_class)+'">\n')
        else:
            self.oufile.write('<table border="1" align="center">\n')


    def closetab(self):
        """
        Input:
            -

        Return:
            -    

        Description:
            Closes a table
        """
        self.oufile.write('</table>\n')


    def gethead(self, cellist, height):
        """
        Input:
            cellist - the cells of a table row
            height  - the height of the table header

        Return:
            -

        Description:
            Writes a table header to the outputfile.
            The column header are taken from the contents of a
            row (usually the first row. In each cell the column
            header can be written to and extracted from each cell.
            those methods are used to get here the column names.
        """
        self.oufile.write('<tr class="axe">\n')
        for index in range(len(cellist)):
#           self.oufile.write('<th bgcolor="#996633"')
            self.oufile.write('<th class="axe"')
            self.oufile.write(' height="'+str(height)+'">\n')
            self.oufile.write(cellist[index].getcolhead())
            self.oufile.write('</th>\n')
        self.oufile.write('</tr>\n')


    def getrow(self, cellist):
        """
        Input:
            cellist - the cells of a table row

        Return:
            -

        Description:
            Writes a table line to the documents. The row
            is defined by an arbitrary list of cells with arbitrary
            content (axe-cells, textcells, imagecells). The cells must
            all have one common method 'gethtml', which gives their
            content as html. That html-strings are then simply written
            to the file.
        """
        self.oufile.write('<tr class="axe">')
        for index in range(len(cellist)):
            self.oufile.write(cellist[index].gethtml())
        self.oufile.write('</tr>\n')



    def setprevpage(self, prev_page):
        """
        Input:
           prev_page - the number of the previous page
        Return:
           -
        Description:
            Small helping method for links and link bars.
        """
        self.prev_page = prev_page


    def setnextpage(self, next_page):
        """
        Input:
           next_page - the number of the next page
        Return:
           -
        Description:
            Small helping method for links and link bars.
        """
        self.next_page = next_page


    def setprevstring(self, prev_string):
        """
        Input:
           prev_string
        Return:
           -
        Description:
            Small helping method for links and link bars.
        """
        self.prev_string = prev_string


    def setnextstring(self, next_string):
        """
        Input:
           next_string
        Return:
           -
        Description:
            Small helping method for links and link bars.
        """
        self.next_string = next_string


    def getlinks(self):
        """
        Input:
            -

        Return:
            -

        Description:
            Creates and writes the html-string for the links
            to the file with the previous and next data set.
            Does this by wrapping the contents
            of 'self.prevpage' and 'self.nextpage' with
            the appropriate html-code. That htnl code
            is immediately written to the file.
        """

        linkstring = '<table>\n<tr>\n'

        if self.prev_page != None:
            linkstring += '<td><b>Previous:</b> <a href="' + self.prev_page
            linkstring += '" rel=prev rev=next>' + self.prev_string + ' </a></td><td>|</td>'

        if self.next_page != None:
            linkstring += '<td><b>Next:</b> <a href="' + self.next_page
            linkstring += '" rel=next rev=prev>' + self.next_string + ' </a></td><td>|</td>'

        if self.over_page != None:
            linkstring += '<td><a href="' + self.over_page + '">' + self.over_string + ' </a></td><td>|</td>'

        if self.info_page != None:
            linkstring += '<td><a href="' + self.info_page + '">' + self.info_string + ' </a></td><td>|</td>'

        if self.inde_page != None:
            linkstring += '<td><a href="' + self.inde_page + '">' + self.inde_string + ' </a></td><td>|</td>'

        linkstring = linkstring + '\n</tr>\n</table>\n<p>\n'
        self.oufile.write('<hr><p>\n')
        self.oufile.write(linkstring)
        self.oufile.write('<p><hr>\n')


    def getlinkbar(self):
        """
        Input:
            -

        Return:
            -

        Description:
            Creates and writes the html-string for the linkbar
            to the file. Does this by wrapping the contents
            of 'self.linkpages' and 'self.linkstrings' with
            the appropriate html-code.
        """
        maxcells = 31
        ncells = 1
        for index in range(len(self.linkpages)):
            if index == 0:
                linkstring = '<table>\n<tr>\n'
                linkstring = linkstring + '<td><b>Objects:</b></td><td><a href="' + \
                             self.linkpages[index] + '">' + self.linkstrings[index] + \
                             '</a></td>\n'
                ncells = ncells+2
            else:
                if ncells > maxcells:
                    linkstring = linkstring + '</tr></table>\n<hr>\n<table><tr><td><b>Objects:</b></td><td><a href="' + \
                                 self.linkpages[index] + '">' + self.linkstrings[index] + \
                                 '</a></td>\n'
                    ncells = 3
                else:
                    linkstring = linkstring + '<td>|</td>' + '<td><a href="' + \
                                 self.linkpages[index] + \
                                 '">' + self.linkstrings[index] + '</a></td>\n'
                    ncells = ncells+2

        linkstring = linkstring + '</tr></table>\n'
        linkstring = linkstring + '<p>\n'
        self.oufile.write('<hr><p>\n')
        self.oufile.write(linkstring)
        self.oufile.write('<p><hr>\n')

#       for index in range(len(self.linkpages)):
#           if index == 0:
#               linkstring = '<table>\n<tr>\n'
#               linkstring = linkstring + '<td><b>Objects:</b></td><td><a href="' + \
#                            self.linkpages[index] + '">' + self.linkstrings[index] + \
#                            '</a></td>\n'
#           else:
#               linkstring = linkstring + '<td>|</td>' + '<td><a href="' + \
#                            self.linkpages[index] + \
#                            '">' + self.linkstrings[index] + '</a></td>\n'
#
#       linkstring = linkstring + '</tr></table>\n'
#       linkstring = linkstring + '<p>\n'
#       self.oufile.write('<hr><p>\n')
#       self.oufile.write(linkstring)
#       self.oufile.write('<p><hr>\n')


    def makelinks(self, nobjects, overview):
        """
        Input:
            nobjects - the number of objects

        Return:
            -

        Description:
            Creates the links to the previous page and the
            next page which show the previous/next set
            of objects. Does not link to overvie/index/info
            pages.
        """

        npages = self.getnpages(nobjects)

        if self.actpage == npages:
            self.this_string = str((self.actpage-1)*self.pagesize+1) + ' - ' + \
                               str(nobjects)
        else:
            self.this_string = str((self.actpage-1)*self.pagesize+1) + ' - ' + \
                               str((self.actpage)*self.pagesize)

        if npages > 1 and self.actpage > 1:
            pnum = self.actpage - 1
            prev_page = self.page_root + '_p' + str(pnum) + '.html'
            prev_string = str((pnum-1)*self.pagesize+1) + ' - ' + \
                          str(pnum*self.pagesize)
            self.setprevpage(prev_page)
            self.setprevstring(prev_string)

        if npages > 1 and self.actpage < npages:
            nnum = self.actpage + 1
            next_page = self.page_root + '_p' + str(nnum) + '.html'
            if self.actpage == npages-1:
                next_string = str(self.actpage*self.pagesize+1) + ' - ' + \
                              str(nobjects)             
            else:
                next_string = str(self.actpage*self.pagesize+1) + ' - ' + \
                              str(nnum*self.pagesize)
            self.setnextpage(next_page)
            self.setnextstring(next_string)

        if overview == 'YES':
            self.over_page    = self.page_root + '_over.html'
            self.over_string  = 'Overview'

            self.info_page = self.page_root + '_info.html'
            self.info_string = 'Info'

            self.inde_page = self.page_root + '_index.html'
            self.inde_string = 'Index'

        if npages > 1 or overview == 'YES':
            self.getlinks()


    def makelinkbar(self, nobjects, overview):
        """
        Input:
            nobjects - the number of objects
            overview - a string indicating whether
                       overview/index/info pages exist
                       or not.

        Return:
            -

        Description:
            Creates the list 'self.linkpages' and 'self.linkstrings'.
            The contents of those two lists is used to generate a
            bar with links to all other pages in the project, that
            means to all other pages showing objects and the
            overview/index/inof pages in case that they exist.
            'self.linkpages' has the filenames of the other
            pages, created from the known rules and naming-roots.
            'self.linkstrings' has the text associated with the
            links as its content.
        """
        self.linkpages   = []
        self.linkstrings = []

        npages = self.getnpages(nobjects)

#       if npages > 1:
        for index in range(npages):
            pnum = index + 1
            if npages == 1:
                lpage = self.page_root + '.html'
            else:
                lpage = self.page_root + '_p' + str(pnum) + '.html'
            if index == npages-1:
                lstring = str((pnum-1)*self.pagesize+1) + ' - ' + str(nobjects)         
            else:
                lstring = str((pnum-1)*self.pagesize+1) + ' - ' + str(pnum*self.pagesize)
            self.linkpages.append(lpage)
            self.linkstrings.append(lstring)
#       if npages > 1:
#           self.getlinkbar()
        if overview == 'YES':
            lpage = self.page_root + '_over.html'
            lstring = 'Overview'
            self.linkpages.append(lpage)
            self.linkstrings.append(lstring)
            lpage = self.page_root + '_info.html'
            lstring = 'Info'
            self.linkpages.append(lpage)
            self.linkstrings.append(lstring)
            lpage = self.page_root + '_index.html'
            lstring = 'Index'
            self.linkpages.append(lpage)
            self.linkstrings.append(lstring)
        if npages > 1 or overview == 'YES':
            self.getlinkbar()


    def gettbody(self):
        """
        Input:
            -
        Return:
            -
        Description:
            Writes the tbody tag into the html-file.
            Not used any more.
        """
        self.oufile.write('<tbody>\n')


    def getnpages(self, nobjects):
        """
        Input:
            nobjects - the total number of objects

        Return:
            npages - the number of pages needed to store
                     all objects

        Description:
            Computes the number of pages needed to show
            'nobjects' objects at a rate of
            'self.pagesize' objects per page. Small
            method to help making the links.
        """
        if math.fmod(nobjects, self.pagesize) == 0:
            npages     = nobjects/self.pagesize
        else:
            npages     = nobjects/self.pagesize + 1

        return npages
