"""
$Revision: 1.3 $ $Date: 2010-08-25 06:47:17 $
Author: Martin Kuemmel
Affiliation: Space Telescope - European Coordinating Facility
"""
__author__ = "Martin Kuemmel <mkuemmel@eso.org>"
__date__ = "$Date: 2010-08-25 06:47:17 $"
__version__ = "$Revision: 1.3 $"
__credits__ = """This software was developed by the ACS group of the Space Telescope -
European Coordinating Facility (ST-ECF). The ST-ECF is a department jointly
run by the European Space Agency and the European Southern Observatory.
It is located at the ESO headquarters at Garching near Munich. The ST-ECF
staff supports the European astronomical community in exploiting the research
opportunities provided by the earth-orbiting Hubble Space Telescope.
"""

class ImageCell:
    """
    Class to create and incorporate an image cell with an image
    in a table. The width, the height can be set. A link
    can be anchored inside that table cell.
    """
    def __init__(self, imname, hclass=None):
        """
        Input:
           imname - the image name

        Return:
           -

        Description:
           Sets the only mandatory cell-attribute, the image
           name and nullifies th eother, potential
           attributes for links, and image size.
        """
        self.imname = imname
        self.anchor = ''
        self.height = ''
        self.width = ''
        self.hclass=hclass

    def setcolhead(self, colhead):
        """
        Input:
            colhead - the column header

        Return:
            -

        Description:
            Sets an instance variable which can be
            used to specify the column header in a table.
        """
        self.colhead=colhead


    def getcolhead(self):
        """
        Input:
            -

        Return:
            -

        Description:
            Returns the column head variable.
        """

        return self.colhead


    def setanchor(self, anchor):
        """
        Input:
            anchor - the anchor name

        Return:
            -

        Description:
            Sets an instance variable which results
            in a link onto the table cell.
        """
        self.anchor=anchor


    def setheight(self, height):
        """
        Input:
            height - the column header

        Return:
            -

        Description:
            Sets an instance variable which defines the
            image (cell) height
        """
        self.height=height


    def setwidth(self, width):
        """
        Input:
            width - the column header

        Return:
            -

        Description:
            Sets an instance variable which deifnes the
            image (cell) width.
        """
        self.width=width


    def gethtml(self):
        """
        Input:
            -

        Return:
            htmlstring - the html-string representing the cell

        Description:
            Returns the the content of an image-cell in html-format.
        """
#  Methodology: Look whethe a cell attribute is set.
#               If yes, put it with the necessary surrounding
#               html code at the roight position inside the
#               output string, which is built up.
        htmlstring = '<td '
        if self.hclass and len(self.hclass) > 0:
            htmlstring += ' class="' + str(self.hclass) + '" '
        if len(self.height) >0:
            htmlstring = htmlstring + 'height="' +  self.height + '" '
        if len(self.width) >0:
            htmlstring = htmlstring + 'width="' +  self.width + '" '

        htmlstring = htmlstring + '>'

        if len(self.anchor) >0:
            htmlstring = htmlstring + '<a name="link' + self.anchor + '">'

        htmlstring = htmlstring + '<img align=middle src="' + self.imname + '" alt="' + self.imname + '"></td>\n'

        return htmlstring
