"""
$Revision: 1.2 $ $Date: 2010-08-25 06:47:17 $
Author: Martin Kuemmel
Affiliation: Space Telescope - European Coordinating Facility
"""
__author__ = "Martin Kuemmel <mkuemmel@eso.org>"
__date__ = "$Date: 2010-08-25 06:47:17 $"
__version__ = "$Revision: 1.2 $"
__credits__ = """This software was developed by the ACS group of the Space Telescope -
European Coordinating Facility (ST-ECF). The ST-ECF is a department jointly
run by the European Space Agency and the European Southern Observatory.
It is located at the ESO headquarters at Garching near Munich. The ST-ECF
staff supports the European astronomical community in exploiting the research
opportunities provided by the earth-orbiting Hubble Space Telescope.
"""

class TextCell:
    """
    Class to create and incorporate an text cell with an text
    in a table. The width, the height can be set. A link
    can be anchored inside that table cell as well as
    a link which points outside to another location.
    """
    def __init__(self, text, html_class=None):
        """
        Input:
           test - the cell text

        Return:
           -

        Description:
           Sets the only mandatory cell-attribute, the text
           to be shown. Nullifies the other, potential
           attributes for links, style, anchors and size.
        """
        self.text   = text
        self.hclass = html_class
        self.anchor = ''
        self.link   = ''
        self.height = ''
        self.width  = ''
        self.bold   = None

    def setcolhead(self, colhead):
        """
        Input:
            colhead - the column header

        Return:
            -

        Description:
            Sets an instance variable which can be
            used to specify the column header in a table.
        """
        self.colhead=colhead

    def getcolhead(self):
        """
        Input:
            -

        Return:
            -

        Description:
            Returns the column head variable.
        """
        return self.colhead

    def setanchor(self, anchor):
        """
        Input:
            colhead - the column header

        Return:
            -

        Description:
            Sets an instance variable which results
            in a link onto the table cell.
        """
        self.anchor=anchor

    def setlink(self, link):
        """
        Input:
            link - the link address

        Return:
            -

        Description:
            Sets an instance variable which results
            in a link from the cell.
        """
        self.link=link

    def setheight(self, height):
        """
        Input:
            height - the cell height

        Return:
            -

        Description:
            Sets an instance variable which defines the
            cell height
        """
        self.height=str(height)

    def setwidth(self, width):
        """
        Input:
            height - the cell width

        Return:
            -

        Description:
            Sets an instance variable which defines the
            cell width
        """
        self.width=str(width)

    def setbold(self):
        """
        Input:
            colhead - the column header

        Return:
            -

        Description:
            Sets an instance variable which results
            that the cell content is shown in bold.
        """
        self.bold = 'YES'

    def gethtml(self):
        """
        Input:
            -

        Return:
            htmlstring - the html-string representing the cell

        Description:
            Returns the the content of an image-cell in html-format.
        """
#  Methodology: Look whethe a cell attribute is set.
#               If yes, put it with the necessary surrounding
#               html code at the right position inside the
#               output string, which is built up.
        htmlstring = '<td '
        if self.hclass and len(self.hclass) > 0:
            htmlstring += ' class="' + str(self.hclass) + '"'
        if len(self.height) > 0:
            htmlstring = htmlstring + ' height="' + self.height + '"'
        if len(self.width) > 0:
            htmlstring = htmlstring + ' width="' + self.width + '"'

        htmlstring = htmlstring + '>'

        if len(self.anchor) > 0:
            htmlstring = htmlstring + '<a name="' + self.anchor + '">'
        if len(self.link) > 0:
            htmlstring = htmlstring + '<a href="' + self.link + '">'
            if self.bold != None:
                htmlstring = htmlstring + '<b>' + self.text + '</b></a>'
                self.text = ''
            else:
                htmlstring = htmlstring + self.text + '</a>'
                self.text = ''

        if len(self.text) > 0:
            if self.bold != None:
                htmlstring = htmlstring + '<b>' + self.text + '</b>'
            else:
                htmlstring = htmlstring + self.text

        htmlstring = htmlstring + '</td>\n'

        return htmlstring

