"""
$Revision: 1.2 $ $Date: 2010-08-25 06:47:17 $
Author: Martin Kuemmel
Affiliation: Space Telescope - European Coordinating Facility
"""
__author__ = "Martin Kuemmel <mkuemmel@eso.org>"
__date__ = "$Date: 2010-08-25 06:47:17 $"
__version__ = "$Revision: 1.2 $"
__credits__ = """This software was developed by the ACS group of the Space Telescope -
European Coordinating Facility (ST-ECF). The ST-ECF is a department jointly
run by the European Space Agency and the European Southern Observatory.
It is located at the ESO headquarters at Garching near Munich. The ST-ECF
staff supports the European astronomical community in exploiting the research
opportunities provided by the earth-orbiting Hubble Space Telescope.
"""

import string

class ColHead:
    def __init__(self, oneline):
        """
        Input:
            oneline - a line from the header of a sextractor
                      catalog
        Return:
            -

        Description:
            The input line is passed to internal methods.
            In those methods the relevant information is
            extracted from the line and put into
            the internal data fields.
        """
        self.colinfo = {}
        self.colinfo['nr']          = self.setnr(oneline)
        self.colinfo['name']        = self.setname(oneline)
        self.colinfo['unit']        = self.setunit(oneline)
        self.colinfo['description'] = self.setdesc(oneline)
        
    def setnr(self, oneline):
        """
        Input:
            oneline - a header line

        Return:
            value - the column number

        Description:
            The input line is split up at blanks.
            The element corresponding to the column number
            is returned.
        """
        value = int(string.split(oneline)[1])
        return value

    def setname(self, oneline):
        """
        Input:
            oneline - a header line

        Return:
            value - the column name

        Description:
            The input line is split up at blanks.
            The element corresponding to the column name
            is returned.
        """
        value = string.split(oneline)[2]

        return value

    def setunit(self, oneline):
        """
        Input:
            oneline - a header line

        Return:
            value - the column unit

        Description:
            The input line is split up at blanks.
            The element corresponding to the column unit
            is returned.
        """
        nitem = len(string.split((oneline)))
        value = string.split(oneline)[nitem-1]
        return value

    def setdesc(self, oneline):
        """
        Input:
            oneline - a header line

        Return:
            value - the column description

        Description:
            The input line is split up at blanks.
            The element corresponding to the column description
            is returned.
        """
        nitem = len(string.split((oneline)))
        if nitem > 3:
            for index in range(3, nitem):
                if index == 3:
                    value = string.split(oneline)[index]
                else:
                    value = value + " " + string.split(oneline)[index]
        else:
            value = 'No desctription'

        return value

    def getnr(self):
        """
        Input:
            -

        Return
            the column number

        Description:
            Returns the column number to the calling
            module
        """
        return self.colinfo['nr']

    def getname(self):
        """
        Input:
            -

        Return
            the column name

        Description:
            Returns the column name to the calling
            module
        """
        return self.colinfo['name']

    def getunit(self):
        """
        Input:
            -

        Return
            the column unit

        Description:
            Returns the column unit to the calling
            module
        """
        return self.colinfo['unit']

    def getdesc(self):
        """
        Input:
            -

        Return
            the column descritption

        Description:
            Returns the column description to the calling
            module
        """
        return self.colinfo['description']

