"""
$Revision: 1.2 $ $Date: 2010-08-25 06:47:17 $
Author: Martin Kuemmel
Affiliation: Space Telescope - European Coordinating Facility
"""
__author__ = "Martin Kuemmel <mkuemmel@eso.org>"
__date__ = "12 January 2004"
__version__ = "1.0 (Jan 12, 2004)"
__credits__ = """This software was developed by the ACS group of the Space Telescope -
European Coordinating Facility (ST-ECF). The ST-ECF is a department jointly
run by the European Space Agency and the European Southern Observatory.
It is located at the ESO headquarters at Garching near Munich. The ST-ECF
staff supports the European astronomical community in exploiting the research
opportunities provided by the earth-orbiting Hubble Space Telescope.
"""

import sys, os, string, math
import aXe2html.sexcat.sextractcat, aXe2html.sexcat.tablecolumn

class SexCorrelator:
    def __init__(self, allsettings):
        self.master   = allsettings['mastercat']
        self.match    = allsettings['matchcat']
        self.outfile  = allsettings['outcat']
        self.sex_master    = aXe2html.sexcat.sextractcat.SexCat(self.master)
        self.sex_match     = aXe2html.sexcat.sextractcat.SexCat(self.match)
        
        if allsettings.has_key('xdistmax'):
            self.xdistmax   = float(allsettings['xdistmax'])
            self.rdistmax   = self.xdistmax
        if allsettings.has_key('ydistmax'):
            self.ydistmax   = float(allsettings['ydistmax'])
        if allsettings.has_key('magdiffmax'):
            self.magdiffmax = float(allsettings['magdiffmax'])

#        success = self.makeprelims()
#        self.corrit()

    def corrit(self):

        success = self.makeprelims()
        if success != 0:
            return success
        
        mentries = 0
        for ii in range(self.nrow_master):
            n_master = []
            n_match  = []
            i_match  = []
            r_match  = []
            for jj in range(self.nrow_match):
                xcoo_master = float(self.sex_master.getval(self.xwo_master, ii))
                ycoo_master = float(self.sex_master.getval(self.ywo_master, ii))
                maga_master = float(self.sex_master.getval(self.mau_master, ii))

                xcoo_match = float(self.sex_match.getval(self.xwo_match, jj))
                ycoo_match = float(self.sex_match.getval(self.ywo_match, jj))
                maga_match = float(self.sex_match.getval(self.mau_match, jj))
                xdiff = math.fabs(xcoo_master - xcoo_match) * \
                        math.cos(ycoo_master*2*math.pi/360.0) * 3600
                ydiff = math.fabs(ycoo_master - ycoo_match) *3600
                rdiff = math.sqrt(xdiff**2 + ydiff**2)
                mdiff = math.fabs(maga_master - maga_match)

#                if xdiff < self.xdistmax and \
#                   ydiff < self.ydistmax and \
#                   mdiff < self.magdiffmax:
                if rdiff < self.rdistmax:
                    id_master = self.sex_master.getval(self.num_master, ii)
                    id_match  = self.sex_match.getval(self.num_match, jj)
                    n_master.append(id_master)
                    n_match.append(id_match)
                    r_match.append(rdiff)
                    i_match.append(jj)
#                    success = self.sex_match.setval(self.num_match, jj, id_master)
#                    success = self.sex_match.setselection(jj)
#                    mentries = mentries + 1
#                    print 'Success: number ',  id_match, 'changed to ', id_master, rdiff
#                   print xcoo_master, ycoo_master, xcoo_match, ycoo_match, rdiff
            if len(n_match) == 1:
                success = self.sex_match.setval(self.num_match, i_match[0], n_master[0])
                success = self.sex_match.setselection(i_match[0])
                mentries = mentries + 1
                print 'Success: number ',n_match[0],'changed to ',n_master[0],r_match[0]
            elif len(n_match) > 1:
                print 'Thinking...'
                rmin = self.rdistmax
                imin = -1
                for index in range(len(n_master)):
                    if r_match[index] < rmin:
                        imin = index
                        rmin = r_match[index]
                success = self.sex_match.setval(self.num_match, i_match[imin], n_master[imin])
                success = self.sex_match.setselection(i_match[imin])
                mentries = mentries + 1
                print 'Success: number ',n_match[imin],'changed to ',n_master[imin],r_match[imin]
                
                    
        print 'Number of matches found: ', mentries

        return int(mentries)

    def printmatchcat(self):
        self.sex_match.printselected()

    def printoutcat(self):
        self.sex_match.printselecttofile(self.outfile)

    def makeprelims(self):
        success = self.sex_master.setaxecols()
        if success != 0:
            return 1
        
        self.nrow_master = self.sex_master.getnrows()
        self.num_master = self.sex_master.n_num
        self.xim_master = self.sex_master.n_xim
        self.yim_master = self.sex_master.n_yim
        self.xwo_master = self.sex_master.n_xwo
        self.ywo_master = self.sex_master.n_ywo
        self.mau_master = self.sex_master.n_mau


        success = self.sex_match.setaxecols()
        if success != 0:
            return 1
        self.nrow_match = self.sex_match.getnrows()
        self.num_match = self.sex_match.n_num
        self.xim_match = self.sex_match.n_xim
        self.yim_match = self.sex_match.n_yim
        self.xwo_match = self.sex_match.n_xwo
        self.ywo_match = self.sex_match.n_ywo
        self.mau_match = self.sex_match.n_mau

        return 0
