"""
$Revision: 1.3 $ $Date: 2010-08-25 06:47:17 $
Author: Martin Kuemmel
Affiliation: Space Telescope - European Coordinating Facility
"""
__author__ = "Martin Kuemmel <mkuemmel@eso.org>"
__date__ = "$Date: 2010-08-25 06:47:17 $"
__version__ = "$Revision: 1.3 $"
___credits__ = """This software was developed by the ACS group of the Space Telescope -
European Coordinating Facility (ST-ECF). The ST-ECF is a department jointly
run by the European Space Agency and the European Southern Observatory.
It is located at the ESO headquarters at Garching near Munich. The ST-ECF
staff supports the European astronomical community in exploiting the research
opportunities provided by the earth-orbiting Hubble Space Telescope.
"""

import sys, os, string,math
from os import environ, putenv, system, path
#from Numeric import *
from array import array
from pyraf import iraf
from pyraf.iraf import stsdas
from pyraf.iraf import tv

def getallkey(fname, ext=None):
    """
    Input:
        fname      - name of the fits file

    Return:
        headerdict - dictionarty with keyword/keyvalue pairs

    Description:
        Reads all headers of a fits file (image) into an ascii
        file via the iraf command 'imhead'. Parses through
        that ascii files and stores all keyword/keyvalue pairs
        in a dictionary.
        Searches then afterwards dedicated for the 'NAXIS' keywords
        which are omitted by 'imhead'. Completeness can not be
        assured since at the time of the writing the various
        appearances of the output was not clear.
    """
    if ext != None:
        irafname = '%s[%s]' % (fname, str(ext))
    else:
        irafname = fname
    headerdict = dict({'inival' : 'null'})
    for headline in iraf.imhead(irafname,long="yes",Stdout=1):
        if headline!="":
            if len(string.split(headline,'=')) > 1:
                hkey = string.strip(string.split(headline,'=')[0])
                hval = string.strip(string.split(headline,'=')[1])
                if len(string.split(hval,'/')) > 1:
                    hval = string.strip(string.split(hval,'/')[0])
                    if len(string.split(hval,"'")) > 1:
                        hval = string.strip(string.split(hval,"'")[1])
                        headerdict[hkey] = hval
                    else:
                        headerdict[hkey] = hval

    for spechead in iraf.hedit(irafname, "NAXIS", value=".", add="NO", addonly="NO", delete="NO", update="NO", show="YES", verify="YES", Stdout=1):
        if len(spechead) > 0:
            hkey = "NAXIS"
            hval = string.strip(string.split(spechead,'=')[1])
            headerdict[hkey] = hval
    for spechead in iraf.hedit(irafname, "NAXIS1", value=".", add="NO", addonly="NO", delete="NO", update="NO", show="YES", verify="YES",Stdout=1):
        if len(spechead) > 0:
            hkey = "NAXIS1"
            hval = string.strip(string.split(spechead,'=')[1])
            headerdict[hkey] = hval
    for spechead in iraf.hedit(irafname, "NAXIS2", value=".", add="NO", addonly="NO", delete="NO", update="NO", show="YES", verify="YES",Stdout=1):
        if len(spechead) > 0:
            hkey = "NAXIS2"
            hval = string.strip(string.split(spechead,'=')[1])
            headerdict[hkey] = hval

    return headerdict

def getonekey(fname,keyname):
    """
    Input:
        fname   - name of a fits file
        keyname - name of the desired keyword

    Return:
        headerdict - dictionary with the keyword/keyvalue
                     pair of the desired keyword.

    Description:
        Looks whether a specific keyword exists in the
        fits file. The procedure is identical to 'getallkey',
        but only the selected keyword is returned.
        If the keyword does not exist, the value 'null'
        is returned.
    """
    headerdict = dict({'inival' : 'null'})
    for headline in iraf.imhead(fname,long="yes",Stdout=1):
        if headline!="":
            if len(string.split(headline,'=')) > 1:
                hkey = string.strip(string.split(headline,'=')[0])
                hval = string.strip(string.split(headline,'=')[1])
                if len(string.split(hval,'/')) > 1:
                    hval = string.strip(string.split(hval,'/')[0])
                    if len(string.split(hval,"'")) > 1:
                        hval = string.strip(string.split(hval,"'")[1])
                        headerdict[hkey] = hval
                    else:
                        headerdict[hkey] = hval


    return headerdict[keyname]
