"""
$Revision: 1.2 $ $Date: 2010-08-25 06:47:17 $
Author: Martin Kuemmel
Affiliation: Space Telescope - European Coordinating Facility
"""
__author__ = "Martin Kuemmel <mkuemmel@eso.org>"
__date__ = "$Date: 2010-08-25 06:47:17 $"
__version__ = "$Revision: 1.2 $"
___credits__ = """This software was developed by the ACS group of the Space Telescope -
European Coordinating Facility (ST-ECF). The ST-ECF is a department jointly
run by the European Space Agency and the European Southern Observatory.
It is located at the ESO headquarters at Garching near Munich. The ST-ECF
staff supports the European astronomical community in exploiting the research
opportunities provided by the earth-orbiting Hubble Space Telescope.
"""

def get_selections(sel_file):
    import string

    # initialize the return
    selection = []
    # initialize the return
    iselection = []

    # open the file and iterate ver each row
    for line in open(sel_file, 'r'):

        # delete white-spaces on both ends
        s_line = string.strip(line)

        # check for NULL-lines and comments
        if len(s_line) > 0 and s_line[0] != '#':

            # append the new selections
            selection.extend(analyze_line(s_line))

    # convert the string s to integers
    for item in selection:
        iselection.append(int(item))
            
    # return the selections
    return iselection


def analyze_line(line):
    import string
    
    # the default string-selectors
    selectors = [',',';',':','|']

    selector = None

    # go over all alternative selectors
    for sel in selectors:

        # if an alternative selector
        # is found, make it to the
        # real selector
        if line.find(sel) > -1:
            selector = sel
            break

    if selector != None:
        # split the line with the selelctor
        list = line.split(selector)
    else:
        list = line.split()

    # return the list
    return list


def make_selections(allsettings):
    import aXe2html.sexcat.sextractcat

    # get the list with selected objects
    slist = get_selections(allsettings['SELEFILE'])

    # store the SExca name
    in_name = allsettings['SEXTRCAT']

    # derive the name of the selected catalogue
    ou_name = get_selcatname(in_name)

    # load the SExcat
    in_cat = aXe2html.sexcat.sextractcat.SexCat(in_name)

    # make the selections
    select_objects(in_cat, slist, allsettings['SORTCOLU'])

    # in case that there is no selection column,
    # set the colum THETA_WORLD to the selection column
    if not allsettings['SORTCOLU']:
        allsettings['SORTCOLU'] = 'THETA_WORLD'
        allsettings['ASCENDIN'] = 'YES'

    # save the catalogue with the
    # selected objects
    in_cat.printselecttofile(ou_name)

    # store the selection catalogue as the
    # new SExtractor catalogue
    allsettings['SEXTRCAT'] = ou_name

    return allsettings

def get_selcatname(in_name):
    import string
    
    # find the last dot
    pos = in_name.rfind('.')

    # append the new ending to
    # the name until the last dot
    new_name = in_name[:pos] + '_sel.cat'

    # return the new name
    return new_name


def select_objects(in_cat, slist, sortcolu):

    # define te axe columns to get the right column numbers
    success = in_cat.setaxecols()

    # deselect all rows
    in_cat.deselect_all()
    
    # go over all rows
    for ii  in range(in_cat.getnrows()):
        
        if int(in_cat.getval(in_cat.n_num, ii)) in slist:

            in_cat.setselection(ii)
            
            if not sortcolu:
                new_index = slist.index(int(in_cat.getval(in_cat.n_num, ii)))
                in_cat.setval(in_cat.n_two, ii, str(new_index))
                
    
